ParallelQuickSort class

Synchronous quick sort retained under its legacy public name.

The implementation is a hybrid divide-and-conquer quick sort and does not spawn isolates. It returns a sorted copy without mutating input.

Inheritance

Constructors

ParallelQuickSort()

Properties

hashCode int
The hash code for this object.
no setterinherited
meta AlgoMetadata
Metadata describing this strategy's characteristics and requirements
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

canApply(List<int> input, SelectorHint hint) bool
Fast check if this strategy can be applied to the given input and hint.
override
execute(List<int> input) List<int>
Execute the algorithm on the given input.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited