IsolateFailure class final

Failure during async execution in isolate.

Inheritance

Constructors

IsolateFailure(String message, [String? details])
const
IsolateFailure.communicationError(Object error)
factory
IsolateFailure.spawnError(Object error)
factory
IsolateFailure.timeout(Duration timeout)
factory

Properties

details String?
Optional additional details about the failure.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable error message.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited